# Diffractogram Tool

Diffractogram shows a result of azimuth integration on 1d plot

- Calibration loads pyFAI calibration files, e.g. in PONI format
- Range defines the integration ranges
- combobox with Units sets x-axis units of the 1d diffractogram plot
- Show/Stop - switches on/off continuous mode of diffractogram update with each image
- Next - (re-)computes a diffractogram for the current image
- combobox with a Number of diffractograms corresponding to different ranges

Ranges and 1d plots colors can be changed in the lavue Configuration by setting Ranges and ROIs Colors`.`

Also in the Configuration the user can change

- Diffractogram size: number of points in the diffractogram
- Correct Solid Angle: correct solid angle flag for diffractogram

A contour plot of diffractograms (collected in time) can be created with use of the Buffering widget

- Buffer size: maximal number of diffractograms in the heat-map plot
- Reset: reset the diffractogram buffer
- Collect/Stop: start or stop collect diffractograms in the buffer
- Main plot: select 2D-plot i.e. Image shows the original image, Buffer <?> shows a buffer for the <?> diffractogram range